@@ -10,7 +10,7 @@ use Carp;
 our $VERSION = $Mail::Builder::VERSION;
 
 before BUILDARGS => sub{
-    carp '<Mail::Builder::Image::Data> is deprecated, use <Mail::Builder::Image> instead';
+    carp '<Mail::Builder::Image::File> is deprecated, use <Mail::Builder::Image> instead';
 };
 
 no Moose;
