@@ -11,7 +11,7 @@ sub encode_mime {
     my ($string) = @_;
 
     return $string
-        if $string !~ m/[^\x00-\x7f]/;
+        if $string !~ m/[^\x00-\x7f]|["']|=\?|\?=/;
     return encode('MIME-Header', $string);
 }
 
